from setuptools import setup, find_packages

setup(
    name='vlinx-util',
    version='0.0.1',
    description='VLINX Python Util',
    long_description='VLINX Python Util Provided by vlinx.io',
    author='vlinx',
    author_email='vlinx@vlinx.io',
    url='https://vlinx.io/',
    license='MIT',
    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=[],
)
